@@ -170,8 +170,6 @@ class AkamaiBackend(base.Backend):
     def __init__(self, target):
         super().__init__(target)
 
-        self._host = self.options.get('host', '127.0.0.1')
-        self._port = int(self.options.get('port', 53))
         self.client = self.init_client()
 
     def init_client(self):
