@@ -16,6 +16,7 @@
 from oslo_log import versionutils
 from oslo_policy import policy
 
+from designate.common import constants
 from designate.common.policies import base
 
 DEPRECATED_REASON = """
@@ -64,7 +65,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="zone_export",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Retrive a Zone Export from the Designate Datastore",
         operations=[
             {
@@ -77,7 +78,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="create_zone_export",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Create Zone Export",
         operations=[
             {
@@ -90,7 +91,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="find_zone_exports",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="List Zone Exports",
         operations=[
             {
@@ -103,7 +104,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="get_zone_export",
         check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Get Zone Exports",
         operations=[
             {
@@ -116,7 +117,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="update_zone_export",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Update Zone Exports",
         operations=[
             {
@@ -129,7 +130,7 @@ rules = [
     policy.DocumentedRuleDefault(
         name="delete_zone_export",
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
-        scope_types=['system', 'project'],
+        scope_types=[constants.PROJECT],
         description="Delete a zone export",
         operations=[
             {
