@@ -11,20 +11,18 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_config import cfg
 from urllib import parse
 
+import designate.conf
 from designate import exceptions
 from designate.objects.adapters import base
 from designate.objects import base as ovoobj_base
 
 
-cfg.CONF.import_opt('api_base_uri', 'designate.api', group='service:api')
-cfg.CONF.import_opt('enable_host_header', 'designate.api', group='service:api')
+CONF = designate.conf.CONF
 
 
 class APIv2Adapter(base.DesignateAdapter):
-    BASE_URI = cfg.CONF['service:api'].api_base_uri.rstrip('/')
     ADAPTER_FORMAT = 'API_v2'
 
     #####################
@@ -33,7 +31,7 @@ class APIv2Adapter(base.DesignateAdapter):
 
     @classmethod
     def render_list(cls, list_objects, *args, **kwargs):
-        r_list = super(APIv2Adapter, cls).render_list(
+        r_list = super().render_list(
             list_objects, *args, **kwargs)
 
         if (cls.MODIFICATIONS['options'].get('links', True) and
@@ -52,7 +50,7 @@ class APIv2Adapter(base.DesignateAdapter):
 
     @classmethod
     def render_object(cls, obj, *args, **kwargs):
-        new_obj = super(APIv2Adapter, cls).render_object(obj, *args, **kwargs)
+        new_obj = super().render_object(obj, *args, **kwargs)
 
         if (cls.MODIFICATIONS['options'].get('links', True) and
                 'request' in kwargs):
@@ -66,7 +64,7 @@ class APIv2Adapter(base.DesignateAdapter):
 
     @classmethod
     def parse(cls, values, output_object, *args, **kwargs):
-        return super(APIv2Adapter, cls).parse(
+        return super().parse(
             cls.ADAPTER_FORMAT, values, output_object, *args, **kwargs)
 
     #####################
@@ -75,20 +73,16 @@ class APIv2Adapter(base.DesignateAdapter):
 
     @classmethod
     def _get_base_url(cls, request):
-        if cfg.CONF['service:api'].enable_host_header:
-            try:
-                return request.host_url
-            except Exception:
-                return cls.BASE_URI
-        else:
-            return cls.BASE_URI
+        if CONF['service:api'].enable_host_header:
+            return request.host_url
+        return CONF['service:api'].api_base_uri.rstrip('/')
 
     @classmethod
     def _get_resource_links(cls, obj, request):
         base_uri = cls._get_base_url(request)
 
         path = cls._get_path(request, obj)
-        return {'self': '%s%s/%s' % (base_uri, path, obj.id)}
+        return {'self': f'{base_uri}{path}/{obj.id}'}
 
     @classmethod
     def _get_path(cls, request, *args):
@@ -110,12 +104,12 @@ class APIv2Adapter(base.DesignateAdapter):
         params = request.GET
 
         # defined in etc/designate/designate.conf.sample
-        limit = cfg.CONF['service:api'].default_limit_v2
+        limit = CONF['service:api'].default_limit_v2
 
         if 'limit' in params:
             limit = params['limit']
             if limit.lower() == 'max':
-                limit = cfg.CONF['service:api'].max_limit_v2
+                limit = CONF['service:api'].max_limit_v2
             else:
                 try:
                     limit = int(limit)
@@ -139,7 +133,7 @@ class APIv2Adapter(base.DesignateAdapter):
 
         base_uri = cls._get_base_url(request)
 
-        href = "%s%s?%s" % (
+        href = '{}{}?{}'.format(
             base_uri,
             cls._get_path(request),
             parse.urlencode(params))
