@@ -19,28 +19,55 @@ from unittest import mock
 import dns
 import dns.exception
 import dns.message
+import dns.name
 import dns.rcode
 import dns.rdatatype
 import dns.zone
 import eventlet
-from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
 import oslotest.base
 
+import designate.conf
 from designate import dnsutils
 from designate import exceptions
 
-CONF = cfg.CONF
+
+CONF = designate.conf.CONF
 
 
 class TestDNSUtils(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestDNSUtils, self).setUp()
+        super().setUp()
         self.useFixture(cfg_fixture.Config(CONF))
 
+    def test_dnspyrecords_to_recordsetlist(self):
+        node = dns.node.Node()
+        node.rdatasets.append(
+            dns.rdataset.from_text('in', 'a', 0, '192.0.2.1')
+        )
+        dnspython_records = {
+            dns.name.Name(labels=[b'ipv4', b'example', b'org', b'']): node
+        }
+        recorset = dnsutils.dnspyrecords_to_recordsetlist(dnspython_records)
+        self.assertEqual(1, len(recorset))
+        self.assertEqual('ipv4.example.org.', recorset[0].name)
+        self.assertIsNone(recorset[0].ttl)
+
+    @mock.patch('socket.getaddrinfo')
+    def test_get_ip_address(self, mock_getaddrinfo):
+        mock_getaddrinfo.return_value = [
+            (socket.AF_INET, socket.SOCK_STREAM, 0, '', ('192.0.2.1', 0))
+        ]
+        self.assertEqual('192.0.2.1', dnsutils.get_ip_address('test'))
+
+    @mock.patch('socket.getaddrinfo')
+    def test_get_ip_address_none(self, mock_getaddrinfo):
+        mock_getaddrinfo.return_value = []
+        self.assertIsNone(dnsutils.get_ip_address('test'))
+
     @mock.patch.object(dns.query, 'udp')
     def test_send_udp_dns_message(self, mock_udp):
-        CONF.set_override('all_tcp', False, 'service:mdns')
+        CONF.set_override('all_tcp', False, 'service:worker')
         dnsutils.send_dns_message('msg', '192.0.2.1', 1234, 1)
         mock_udp.assert_called_with(
             'msg', '192.0.2.1', port=1234, timeout=1
@@ -48,7 +75,7 @@ class TestDNSUtils(oslotest.base.BaseTestCase):
 
     @mock.patch.object(dns.query, 'tcp')
     def test_send_tcp_dns_message(self, mock_tcp):
-        CONF.set_override('all_tcp', True, 'service:mdns')
+        CONF.set_override('all_tcp', True, 'service:worker')
         dnsutils.send_dns_message('msg', '192.0.2.1', 1234, 1)
         mock_tcp.assert_called_with(
             'msg', '192.0.2.1', port=1234, timeout=1
@@ -57,10 +84,6 @@ class TestDNSUtils(oslotest.base.BaseTestCase):
     def test_all_tcp_default(self):
         self.assertEqual(False, dnsutils.use_all_tcp())
 
-    def test_all_tcp_using_mdns(self):
-        CONF.set_override('all_tcp', True, 'service:mdns')
-        self.assertEqual(True, dnsutils.use_all_tcp())
-
     def test_all_tcp_using_worker(self):
         CONF.set_override('all_tcp', True, 'service:worker')
         self.assertEqual(True, dnsutils.use_all_tcp())
@@ -68,10 +91,6 @@ class TestDNSUtils(oslotest.base.BaseTestCase):
     def test_xfr_default(self):
         self.assertEqual(10, dnsutils.xfr_timeout())
 
-    def test_xfr_timeout_set_using_mdns(self):
-        CONF.set_override('xfr_timeout', 30, 'service:mdns')
-        self.assertEqual(30, dnsutils.xfr_timeout())
-
     def test_xfr_timeout_set_using_worker(self):
         CONF.set_override('xfr_timeout', 40, 'service:worker')
         self.assertEqual(40, dnsutils.xfr_timeout())
@@ -79,7 +98,7 @@ class TestDNSUtils(oslotest.base.BaseTestCase):
 
 class TestDoAfxr(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestDoAfxr, self).setUp()
+        super().setUp()
         self.useFixture(cfg_fixture.Config(CONF))
 
     @mock.patch.object(dns.query, 'xfr')
@@ -191,15 +210,15 @@ class TestDoAfxr(oslotest.base.BaseTestCase):
 
 class TestDNSMessages(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestDNSMessages, self).setUp()
+        super().setUp()
         self.useFixture(cfg_fixture.Config(CONF))
 
     @mock.patch.object(dnsutils, 'send_dns_message')
     def test_notify(self, mock_send_dns_message):
-        dnsutils.notify('notify.test.', 'localhost', port=54)
+        dnsutils.notify('notify.test.', '203.0.113.1', port=54)
 
         mock_send_dns_message.assert_called_with(
-            mock.ANY, 'localhost', port=54, timeout=10
+            mock.ANY, '203.0.113.1', port=54, timeout=10
         )
 
         query = mock_send_dns_message.call_args[0][0]
@@ -217,10 +236,10 @@ class TestDNSMessages(oslotest.base.BaseTestCase):
 
     @mock.patch.object(dnsutils, 'send_dns_message')
     def test_soa(self, mock_send_dns_message):
-        dnsutils.soa_query('soa.test.', 'localhost', port=54)
+        dnsutils.soa_query('soa.test.', '203.0.113.1', port=54)
 
         mock_send_dns_message.assert_called_with(
-            mock.ANY, 'localhost', port=54, timeout=10
+            mock.ANY, '203.0.113.1', port=54, timeout=10
         )
 
         query = mock_send_dns_message.call_args[0][0]
@@ -247,7 +266,7 @@ class TestDNSMessages(oslotest.base.BaseTestCase):
         mock_send_dns_message.return_value = mock_result
 
         self.assertEqual(
-            5, dnsutils.get_serial('serial.test.', 'localhost', port=54)
+            5, dnsutils.get_serial('serial.test.', '203.0.113.1', port=54)
         )
 
         query = mock_send_dns_message.call_args[0][0]
@@ -270,7 +289,7 @@ class TestDNSMessages(oslotest.base.BaseTestCase):
         mock_send_dns_message.return_value = mock_result
 
         self.assertFalse(
-            dnsutils.get_serial('serial.test.', 'localhost', port=54)
+            dnsutils.get_serial('serial.test.', '203.0.113.1', port=54)
         )
 
     @mock.patch.object(dnsutils, 'send_dns_message')
@@ -283,5 +302,5 @@ class TestDNSMessages(oslotest.base.BaseTestCase):
         mock_send_dns_message.return_value = mock_result
 
         self.assertFalse(
-            dnsutils.get_serial('serial.test.', 'localhost', port=54)
+            dnsutils.get_serial('serial.test.', '203.0.113.1', port=54)
         )
