@@ -14,24 +14,56 @@ from unittest import mock
 
 import jinja2
 from oslo_concurrency import processutils
-from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
 import oslotest.base
 
+import designate.conf
 from designate import exceptions
-from designate.tests import fixtures
+from designate.tests import base_fixtures
 from designate import utils
 
-CONF = cfg.CONF
+
+CONF = designate.conf.CONF
 
 
 class TestUtils(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestUtils, self).setUp()
-        self.stdlog = fixtures.StandardLogging()
+        super().setUp()
+        self.stdlog = base_fixtures.StandardLogging()
         self.useFixture(cfg_fixture.Config(CONF))
         self.useFixture(self.stdlog)
 
+    def test_validate_uuid(self):
+        @utils.validate_uuid('zone_id')
+        def validate_uuid(cls, zone_id):
+            return True
+        self.assertTrue(
+            validate_uuid(None, '6a8caf9d-679e-4fc1-80e9-13496f6a783f')
+        )
+
+    def test_validate_invalid_uuid(self):
+        @utils.validate_uuid('zone_id')
+        def validate_uuid(cls, zone_id):
+            return True
+
+        self.assertRaisesRegex(
+            exceptions.InvalidUUID,
+            'Invalid UUID zone_id: 62f89e5f088c7',
+            validate_uuid, None, '62f89e5f088c7'
+        )
+
+    def test_validate_uuid_no_arguments(self):
+        @utils.validate_uuid('zone_id')
+        def validate_uuid(cls):
+            return
+        self.assertRaises(exceptions.NotFound, validate_uuid)
+
+    def test_invalid_uuid_no_argument_provided(self):
+        @utils.validate_uuid('zone_id')
+        def validate_uuid(cls):
+            return
+        self.assertRaises(exceptions.NotFound, validate_uuid, None)
+
     @mock.patch('os.path.exists')
     @mock.patch('os.path.abspath')
     def test_find_config(self, mock_abspath, mock_path_exists):
@@ -185,7 +217,7 @@ class TestUtils(oslotest.base.BaseTestCase):
 
     @mock.patch.object(utils, 'resource_string')
     def test_load_template(self, mock_resource_string):
-        mock_resource_string.return_value = 'Hello {{name}}'.encode('utf-8')
+        mock_resource_string.return_value = b'Hello {{name}}'
 
         template = utils.load_template('bind9-zone.jinja2')
 
@@ -193,7 +225,7 @@ class TestUtils(oslotest.base.BaseTestCase):
 
     @mock.patch.object(utils, 'resource_string')
     def test_load_template_keep_trailing_newline(self, mock_resource_string):
-        mock_resource_string.return_value = 'Hello {{name}}'.encode('utf-8')
+        mock_resource_string.return_value = b'Hello {{name}}'
 
         template = utils.load_template('bind9-zone.jinja2')
 
@@ -212,14 +244,6 @@ class TestUtils(oslotest.base.BaseTestCase):
 
         self.assertEqual('Hello World', result)
 
-    def test_is_uuid_like(self):
-        self.assertTrue(
-            utils.is_uuid_like('ce9fcd6b-d546-4397-8a49-8ceaec37cb64')
-        )
-
-    def test_is_not_uuid_like(self):
-        self.assertFalse(utils.is_uuid_like('678'))
-
     def test_split_host_port(self):
         host, port = utils.split_host_port('abc:25')
         self.assertEqual(('abc', 25), (host, port))
@@ -362,16 +386,16 @@ class TestUtils(oslotest.base.BaseTestCase):
         mock_sock = mock.MagicMock()
         mock_sock_impl.return_value = mock_sock
 
-        utils.bind_tcp('127.0.0.1', 53, 100, 1)
+        utils.bind_tcp('203.0.113.1', 53, 100, 1)
 
         mock_sock.settimeout.assert_called_once_with(1)
 
-        mock_sock.bind.assert_called_once_with(('127.0.0.1', 53))
+        mock_sock.bind.assert_called_once_with(('203.0.113.1', 53))
 
         mock_sock.listen.assert_called_once_with(100)
 
         self.assertIn(
-            'Opening TCP Listening Socket on 127.0.0.1:53',
+            'Opening TCP Listening Socket on 203.0.113.1:53',
             self.stdlog.logger.output
         )
 
@@ -381,9 +405,9 @@ class TestUtils(oslotest.base.BaseTestCase):
         mock_sock = mock.MagicMock()
         mock_sock_impl.return_value = mock_sock
 
-        mock_sock.getsockname.return_value = ('127.0.0.1', random_port)
+        mock_sock.getsockname.return_value = ('203.0.113.1', random_port)
 
-        utils.bind_tcp('127.0.0.1', 0, 100, 1)
+        utils.bind_tcp('203.0.113.1', 0, 100, 1)
 
         self.assertIn(
             'Listening on TCP port %(port)d' % {'port': random_port},
@@ -396,7 +420,7 @@ class TestUtils(oslotest.base.BaseTestCase):
         mock_sock_impl.return_value = mock_sock
         mock_sock.setsockopt.side_effect = [None, None, AttributeError, None]
 
-        utils.bind_tcp('127.0.0.1', 53, 100, 1)
+        utils.bind_tcp('203.0.113.1', 53, 100, 1)
 
         self.assertIn(
             'SO_REUSEPORT not available, ignoring.',
@@ -408,14 +432,14 @@ class TestUtils(oslotest.base.BaseTestCase):
         mock_sock = mock.MagicMock()
         mock_sock_impl.return_value = mock_sock
 
-        utils.bind_udp('127.0.0.1', 53)
+        utils.bind_udp('203.0.113.1', 53)
 
         mock_sock.settimeout.assert_called_once_with(1)
 
-        mock_sock.bind.assert_called_once_with(('127.0.0.1', 53))
+        mock_sock.bind.assert_called_once_with(('203.0.113.1', 53))
 
         self.assertIn(
-            'Opening UDP Listening Socket on 127.0.0.1:53',
+            'Opening UDP Listening Socket on 203.0.113.1:53',
             self.stdlog.logger.output
         )
 
@@ -425,9 +449,9 @@ class TestUtils(oslotest.base.BaseTestCase):
         mock_sock = mock.MagicMock()
         mock_sock_impl.return_value = mock_sock
 
-        mock_sock.getsockname.return_value = ('127.0.0.1', random_port)
+        mock_sock.getsockname.return_value = ('203.0.113.1', random_port)
 
-        utils.bind_udp('127.0.0.1', 0)
+        utils.bind_udp('203.0.113.1', 0)
 
         self.assertIn(
             'Listening on UDP port %(port)d' % {'port': random_port},
@@ -440,7 +464,7 @@ class TestUtils(oslotest.base.BaseTestCase):
         mock_sock_impl.return_value = mock_sock
         mock_sock.setsockopt.side_effect = [None, AttributeError]
 
-        utils.bind_udp('127.0.0.1', 53)
+        utils.bind_udp('203.0.113.1', 53)
 
         self.assertIn(
             'SO_REUSEPORT not available, ignoring.',
