@@ -15,7 +15,7 @@
 # How many seconds to wait for the API to be responding before giving up
 API_RESPONDING_TIMEOUT=20
 
-if ! timeout ${API_RESPONDING_TIMEOUT} sh -c "while ! curl -s http://127.0.0.1:9001/ 2>/dev/null | grep -q 'v1' ; do sleep 1; done"; then
+if ! timeout ${API_RESPONDING_TIMEOUT} sh -c "while ! curl -s http://127.0.0.1:9001/ 2>/dev/null | grep -q 'v2' ; do sleep 1; done"; then
     echo "The Designate API failed to respond within ${API_RESPONDING_TIMEOUT} seconds"
     exit 1
 fi
@@ -23,10 +23,10 @@ fi
 echo "Successfully contacted the Designate API"
 
 # Where Designate and Tempest code lives
-DESIGNATE_DIR=${DESIGNATE_DIR:-/opt/stack/new/designate}
-TEMPEST_DIR=${TEMPEST_DIR:-/opt/stack/new/tempest}
-
+DESIGNATE_DIR=${DESIGNATE_DIR:-"$BASE/new/designate"}
+TEMPEST_DIR=${TEMPEST_DIR:-"$BASE/new/tempest"}
 
 pushd $DESIGNATE_DIR
 export TEMPEST_CONFIG=$TEMPEST_DIR/etc/tempest.conf
 tox -e functional -- --concurrency 4
+popd
